# DVQ - DNA Validation and Quick comparisons 
A package with some useful functions to compare DNA sequences both visually and statistically 

## Commands:

* How to use dvq
```python
from dvq import visual

visual.plot_2d_comparison([seqs_1, seqs_2], ['seq_1', 'seq_2'])

```

![An example graphic comparing sequences ](Untitled.png "2D Comparison - Same virus")